@@ -1,11 +1,12 @@
-package Getopt::Long::Complete;
-
 ## no critic (Modules::ProhibitAutomaticExportation)
 
-our $DATE = '2020-02-27'; # DATE
-our $VERSION = '0.311'; # VERSION
+package Getopt::Long::Complete;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-28'; # DATE
+our $DIST = 'Getopt-Long-Complete'; # DIST
+our $VERSION = '0.312'; # VERSION
 
-use 5.010001;
 use strict;
 use warnings;
 
@@ -13,12 +14,27 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
                     GetOptions
+
+                    $REQUIRE_ORDER $PERMUTE $RETURN_IN_ORDER
                );
 our @EXPORT_OK = qw(
-                    GetOptions
                     GetOptionsWithCompletion
+
+                    GetOptionsFromArray
+                    GetOptionsFromString
+                    Configure
+                    HelpMessage
+                    VersionMessage
                );
 
+# we don't want to always load Getopt::Long to avoid startup overhead.
+our ($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER) = (0..2); # copied from Getopt::Long
+sub GetOptionsFromArray  { require Getopt::Long; goto &Getopt::Long::GetOptionsFromArray }
+sub GetOptionsFromString { require Getopt::Long; goto &Getopt::Long::GetOptionsFromString }
+sub Configure            { require Getopt::Long; goto &Getopt::Long::Configure }
+sub HelpMessage          { require Getopt::Long; goto &Getopt::Long::HelpMessage }
+sub VersionMessage       { require Getopt::Long; goto &Getopt::Long::VersionMessage }
+
 # default follows Getopt::Long
 our $opt_permute = $ENV{POSIXLY_CORRECT} ? 0 : 1;
 our $opt_pass_through = 0;
@@ -61,7 +77,7 @@ sub GetOptionsWithCompletion {
             ($words,$cword) = @{ Complete::Bash::join_wordbreak_words($words, $cword) };
         } elsif ($ENV{COMMAND_LINE}) {
             require Complete::Tcsh;
-            $shell //= 'tcsh';
+            $shell ||= 'tcsh';
             ($words, $cword) = @{ Complete::Tcsh::parse_cmdline() };
         }
 
@@ -131,7 +147,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.311 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2020-02-27.
+This document describes version 0.312 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2020-02-28.
 
 =head1 SYNOPSIS
 
@@ -232,34 +248,49 @@ You can use Perl's C<local> to localize the effect.
 
 =head2 $opt_permute
 
-Bool. Default: 1 (or 0 if POSIXLY_CORRECT).
+Bool. Default: 1 (or 0 if POSIXLY_CORRECT). Not exported.
 
 =head2 $opt_pass_through
 
-Bool. Default: 0.
+Bool. Default: 0. Not exported.
 
 =head2 $opt_bundling
 
-Bool. Default: 1.
+Bool. Default: 1. Not exported.
+
+=head2 $REQUIRE_ORDER
+
+Integer. Constant. Value is 0. Exported by default, to be compatible with
+Getopt::Long.
+
+=head2 $PERMUTE
+
+Integer. Constant. Value is 1. Exported by default, to be compatible with
+Getopt::Long.
+
+=head2 $RETURN_IN_ORDER
+
+Integer. Constant. Value is 2. Exported by default, to be compatible with
+Getopt::Long.
 
 =head1 INCOMPATIBILITIES
 
-Although you can use Getopt::Long::Complete (GLC) as a drop-in replacement for
-Getopt::Long (GL) most of the time, there are some incompatibilities or
-unsupported features:
+Getopt::Long::Complete (GLC) provides all the same exports as Getopt::Long (GL),
+for example L</GetOptions> (exported by default), L</GetOptionsFromArray>,
+L</Configure>, etc.
+
+Aside from L<GetOptions> which has an extra behavior to support completion, all
+the other routines of GLC behave exactly the same as GL.
+
+However, there are some incompatibilities or unsupported features:
 
 =over
 
 =item * GLC does not allow passing configure options during import
 
-GLC only supports running under a specific set of modes anyway: C<bundling>,
-C<no_ignore_case>. Other non-default settings have not been tested and probably
-not supported.
+=item * GLC's GetOptions only supports running under a specific set of modes: C<bundling>, C<no_ignore_case>.
 
-=item * Aside from GetOptions, no other GL functions are currently supported
-
-This include C<GetOptionsFromArray>, C<GetOptionsFromString>, C<Configure>,
-C<HelpMessage>, C<VersionMessage>.
+Other non-default settings have not been tested and probably not supported.
 
 =back
 
@@ -271,8 +302,9 @@ Usage:
 
  GetOptions([ \%hash, ] @spec)
 
-Will call Getopt::Long's GetOptions, except when COMP_LINE environment variable
-is defined, in which case will print completion reply to STDOUT and exit.
+Exported by default. Will call Getopt::Long's GetOptions, except when COMP_LINE
+environment variable is defined, in which case will print completion reply to
+STDOUT and exit.
 
 B<Note: Will temporarily set Getopt::Long configuration as follow: bundling,
 no_ignore_case, gnu_compat, no_getopt_compat, permute (if POSIXLY_CORRECT
@@ -286,13 +318,33 @@ Usage:
 
  GetOptionsWithCompletion(\&completion, [ \%hash, ] @spec)
 
-Just like C<GetOptions>, except that it accepts an extra first argument
-C<\&completion> containing completion routine for completing option I<values>
-and arguments. This will be passed as C<completion> argument to
+Exported on demand. Just like C<GetOptions>, except that it accepts an extra
+first argument C<\&completion> containing completion routine for completing
+option I<values> and arguments. This will be passed as C<completion> argument to
 L<Complete::Getopt::Long>'s C<complete_cli_arg>. See that module's documentation
 on details of what is passed to the routine and what return value is expected
 from it.
 
+=head2 GetOptionsFromArray
+
+Exported on demand. Will just call Getopt::Long's version.
+
+=head2 GetOptionsFromString
+
+Exported on demand. Will just call Getopt::Long's version.
+
+=head2 Configure
+
+Exported on demand. Will just call Getopt::Long's version.
+
+=head2 HelpMessage
+
+Exported on demand. Will just call Getopt::Long's version.
+
+=head2 VersionMessage
+
+Exported on demand. Will just call Getopt::Long's version.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Long-Complete>.
